#
# spec file for package rbenv
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rbenv
Version:        1.2.0
Release:        1.4
BuildArch:      noarch
License:        MIT
Group:          Development/Languages/Ruby
URL:            https://github.com/rbenv/rbenv
Summary:        Simple Ruby version Management
Source0:        https://github.com/rbenv/rbenv/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
%if %{undefined sle_version}
BuildRequires:  bats
BuildRequires:  git
BuildRequires:  procps
%endif
Requires:       procps
Recommends:     ruby-build

%description
rbenv does…

- Let you change the global Ruby version on a per-user basis.
- Provide support for per-project Ruby versions.
- Allow you to override the Ruby version with an environment variable.

In contrast with rvm, rbenv does not…

- Need to be loaded into your shell. Instead, rbenv's shim approach works by adding a directory to your $PATH.
- Override shell commands like cd. That's dangerous and error-prone.
- Have a configuration file. There's nothing to configure except which version of Ruby you want to use.
- Install Ruby. You can build and install Ruby yourself, or use ruby-build to automate the process.
- Manage gemsets. Bundler is a better way to manage application dependencies. If you have projects that are not yet using Bundler you can install the rbenv-gemset plugin.
- Require changes to Ruby libraries for compatibility. The simplicity of rbenv means as long as it's in your $PATH, nothing else needs to know about it.
- Prompt you with warnings when you switch to a project. Instead of executing arbitrary code, rbenv reads just the version name from each project. There's nothing to "trust."

%package bash-completion
Summary:        Bash completion for %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
The official bash completion script for %{name}.

%package zsh-completion
Summary:        ZSH completion for %{name}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
The official zsh completion script for %{name}.

%prep
%setup -q

%build

%install
install -Dm0755 libexec/* -t %{buildroot}%{_bindir}

install -Dm0644 completions/rbenv.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dm0644 completions/rbenv.zsh %{buildroot}%{_datadir}/zsh/site-functions/_%{name}

mkdir -p %{buildroot}/usr/lib/rbenv
cp -r rbenv.d/* %{buildroot}/usr/lib/rbenv

sed -i 's|#!/usr/bin/env bash|#!/bin/bash|g' %{buildroot}%{_bindir}/*

%check
%if %{undefined sle_version}
bats test
%endif

%files
%license LICENSE
%doc README.md
%{_bindir}/rbenv*
/usr/lib/rbenv

%files bash-completion
%{_datadir}/bash-completion

%files zsh-completion
%{_datadir}/zsh

%changelog
* Tue May 24 2022 Lukas Müller <expeehaa@outlook.com>
- Run "osc service runall format_spec_file".
* Mon May 23 2022 Lukas Müller <expeehaa@outlook.com>
- Remove unnecessary conflict with a potential rvm package.
* Mon May 23 2022 Lukas Müller <expeehaa@outlook.com>
- Re-enable skipped tests by requiring the procps package.
- Use /usr/lib/rbenv instead of /etc/rbenv.d for hooks.
- Factor bash and zsh completions out into subpackages.
- Add %%changelog macro at the end of the spec file.
- Remove _service file.
- Remove broken completion path fix without replacement.
* Wed Nov 10 2021 Lukas Müller <expeehaa@outlook.com>
- Fix completion installation.
- Install hooks.
* Fri Nov  5 2021 Müller <expeehaa@outlook.com>
- Enable tests on openSUSE in %%check step.
* Fri Nov  5 2021 Lukas Müller <expeehaa@outlook.com>
- Update to 1.2.0
- Changelog: https://github.com/rbenv/rbenv/releases/tag/v1.2.0
* Sun Oct  4 2020 Michele Bologna <Michele.Bologna@suse.com>
- Update to 1.1.2
- Changelog: https://github.com/rbenv/rbenv/releases/tag/v1.1.2
* Fri Feb  9 2018 michele.bologna@suse.com
- Update to 1.1.1
- Changelog: https://github.com/rbenv/rbenv/releases/tag/v1.1.1
* Tue Mar 14 2017 mamorales@suse.com
- update to 1.1.0
- see https://github.com/rbenv/rbenv/releases/tag/v1.1.0
* Wed Dec 30 2015 dmacvicar@suse.de
- update to 1.0.0
- see https://github.com/rbenv/rbenv/releases/tag/v1.0.0
* Fri Oct 18 2013 dmacvicar@suse.de
- update to 0.4.0
* Wed Jan  4 2012 dmacvicar@suse.de
- update to 0.3.0
* Wed Jan  4 2012 dmacvicar@suse.de
- add BuildRoot tag
* Thu Dec  8 2011 dmacvicar@suse.de
- sync with git master
* Thu Nov 24 2011 dmacvicar@suse.de
- Move completions to /usr/share/rbenv/completions
- remove patch for completions and just modify rbenv-init
  to ouput the right path.
* Wed Nov 16 2011 dmacvicar@suse.de
- patch rbenv-init to not source completions as we install them
  in completions.d
* Wed Nov 16 2011 dmacvicar@suse.de
- initial package for 0.2.1
